@@ -72,14 +72,17 @@ test_that("ComplementSet", {
 })
 
 test_that("ProductSet", {
-  expect_equal(
-    setproduct(Set$new(1, 2), Set$new(3, 4), simplify = TRUE) & Set$new(Tuple$new(1, 4)),
+  useUnicode(FALSE)
+  obj <- setproduct(Set$new(1, 2), Set$new(3, 4), simplify = TRUE) &
     Set$new(Tuple$new(1, 4))
-  )
-  expect_equal(
-    (Set$new(1, 2) * Set$new(3, 4)) & Set$new(Tuple$new(1, 4), Tuple$new(5, 6)),
-    Set$new(Tuple$new(1, 4))
-  )
-  expect_equal((Set$new(1, 2) * Set$new(3, 4)) & Tuple$new(1, 4), Set$new())
-  expect_message((Set$new(1, 2) * Set$new(3, 4)) & (Set$new(1, 2) * Set$new(3, 4)), "currently not implemented")
+  expect_equal(as.character(obj), "{(1, 4)}")
+  obj <- (Set$new(1, 2) * Set$new(3, 4)) &
+    Set$new(Tuple$new(1, 4), Tuple$new(5, 6))
+  expect_equal(as.character(obj), "{(1, 4)}")
+  expect_equal(as.character((Set$new(1, 2) * Set$new(3, 4)) & Tuple$new(1, 4)),
+    "{}")
+  expect_message(
+    (Set$new(1, 2) * Set$new(3, 4)) & (Set$new(1, 2) * Set$new(3, 4)),
+    "currently not implemented")
+  useUnicode(TRUE)
 })
